==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_my.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=my
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'လာမည့် ဆောင်ပါးအသစ်များ အ​တွက်သာ (သိုလောင် သိမ်းဆည်းထားသည်များနှင့်မဆိုင်)',
	'bouton_radio_articles_tous' => 'လုံးဝခြွင်းချက်မရှိ ဆောင်းပါးများ အလုံးသို့',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'ဆောင်းပါးများ အလုံးသို့၊ သို့သော် ဖိုရမ်ပိတ်ထားသော ဆောင်းပါးများမပါ',
	'bouton_radio_enregistrement_obligatoire' => 'မှတ်ပုံတင်ရန် လိုအပ်သည် (သုံးစွဲသူများ အနေဖြင့် အီးမေးလ်လိပ်စာ ပေးထားရပါမည်)',
	'bouton_radio_moderation_priori' => 'ကြိုတင် ထိန်းသိမ်းထားခြင်း (ပါဝင်ရေးသားချက်များသည် ကြီးကြပ်သူမှ စစ်ဆေးအတည်ပြုပြီးမှသာ အများဆိုင်စာမျက်နှာတွင် ပေါ်လာမည်)', # MODIF
	'bouton_radio_modere_abonnement' => 'မှတ်ပုံတင်ထားရန် လိုအပ်သည်',
	'bouton_radio_modere_posteriori' => 'နောက်မှ ထိန်းသိမ်းခြင်း', # MODIF
	'bouton_radio_modere_priori' => 'ကြိုတင် ထိန်းသိမ်းထားခြင်း', # MODIF
	'bouton_radio_publication_immediate' => 'ချက်ချင်းထုတ်ပြန်ခြင်းအတွက် သတင်းအချက်အလက် (ပါဝင်ရေးသားချက်များ ပို့​ပြီးပြီးခြင်း ဖော်ပြမည်၊ အဲဒီနောက် ကြီးကြပ်သူများမှ ပယ်ဖျက်နိုင်သည်)',

	// F
	'form_pet_message_commentaire' => 'မှတ်ချက် တစ်စုံတစ်ရာ ပေးလိုပါသလား?',
	'forum' => 'ဖိုရမ်',
	'forum_acces_refuse' => 'ဤဖိုရမ်သို့ ဝင်ရောက်ခွင့် မရှိတော့ပါ',
	'forum_attention_dix_caracteres' => '<b>သတိပေးချက်!</b> သင့်စာစောင်သည် အနည်းဆုံး စာလုံး၁ဝလုံးနှင့် အထက်ပါဝင်သင့်သည်',
	'forum_attention_trois_caracteres' => '<b>သတိပေးချက်!</b> သင့်ခေါင်းစဉ်သည် အနည်းဆုံး စာလုံး၃လုံးနှင့် အထက်ပါဝင်သင့်သည်',
	'forum_attention_trop_caracteres' => '<b>သတိပေးချက် !</b> သင့်စာစောင် (@compte@ characters) သည် သိမ်းဆည်းရန် ရှည်လွန်းသည်၊ ​အများဆုံး စာလုံး @max@သာ ပါဝင်သင့်သည်', # MODIF
	'forum_avez_selectionne' => 'သင်ရွေးချယ်ခဲ့ပြီးပြီ',
	'forum_cliquer_retour' => 'ဤနေရာကို <a href=\'@retour_forum@\'>နှိပ်ပြီး</a> ဆက်သွားပါ',
	'forum_forum' => 'ဖိုရမ်',
	'forum_info_modere' => 'ဤဖိုရမ်သည် အတည်ပြုချက်လိုအပ်​သည်၊ သင့်ပါဝင်ရေးသားမှုသည် ဆိုက်ကြီးကြပ်သူမှ အတည်ပြုပြီးရင် ပေါ်လာပါလိမ့်မည်', # MODIF
	'forum_lien_hyper' => '<b>Hypertext ဆက်သွယ်မှု</b> (optional)', # MODIF
	'forum_message_definitif' => 'ဆိုက်သို့ပို့ပြီးကြောင်း နောက်ဆုံးအကြောင်းကြားခြင်း',
	'forum_message_trop_long' => 'သင့်စာစောင် အလွန်ရှည်ပါသည်၊ အများဆုံး စာလုံး ၂ဝဝဝဝ သာရှိသင့်သည်', # MODIF
	'forum_ne_repondez_pas' => 'ဤမေးလ်ကို တိုက်ရိုက် အကြောင်းမပြန်ပါနှင့်၊ အောက်ပါလိပ်စာမှ ပြန်ပါ', # MODIF
	'forum_page_url' => '(သင့်ဆောင်ပါး ထုတ်ဝေမှုကို ဒီစာစောင်မ ညွှန်းထားတယ်ဆိုရင်တော့၊ အောက်ဖော်ပြပါနေရာတွင် စာမျက်နှာခေါင်းစဉ်နှင့် လိပ်စာကိုထည့်သွင်းပါ။)',
	'forum_poste_par' => 'သင့်ဆောင်းပါး \\"@titre@\\" တင်သွင်းပြီးကြောင်း @parauteur@', # MODIF
	'forum_qui_etes_vous' => '<b>သင်ဘယ်သူလဲ?</b> (optional)', # MODIF
	'forum_texte' => 'သင့်စာစောင်၏ စာသားများ', # MODIF
	'forum_titre' => 'အကြောင်းအရာ', # MODIF
	'forum_url' => 'ဝက်ဘ်လိပ်စာ', # MODIF
	'forum_valider' => 'ဤရွေးချယ်မှုကို အတည်ပြုရန်',
	'forum_voir_avant' => 'စာစောင်မတင်သွင်းမှီ အရင်ကြည့်ရှုရန်', # MODIF
	'forum_votre_email' => 'သင့်အီးမေးလ်လိပ်စာ', # MODIF
	'forum_votre_nom' => 'သင့်နာမည်', # MODIF
	'forum_vous_enregistrer' => 'သင့်ကိုပေးထားသော မှတ်ပုံတင်နံပါတ်နှင့်ဝင်ပါ သို့မဟုတ် ဤဖိုရမ်ထဲ အထူးနေရာမှ ပါဝင် ရန် အရင်မှတ်ပုံတင်ပါ',
	'forum_vous_inscrire' => 'မှတ်ပုံတင်ရန်',

	// I
	'icone_poster_message' => 'စာတစောင်ပို့ပါ',
	'icone_suivi_forum' => 'နောက်ဆက်တွဲဖိုရမ် @nb_forums@ ပါဝင်မှု(များ)',
	'icone_suivi_forums' => 'ဖိုရမ်ကို စီမံရန်',
	'icone_supprimer_message' => 'ဤစာစောင်ကို ပယ်ဖျက်ရန်',
	'icone_valider_message' => 'ဤစာစောင်ကို အတည်ပြုရန်',
	'info_activer_forum_public' => '<i>အများသုံးဖိုရမ်သို့ ဝင်ရောက်ရန်အတွက် အခြားထိန်းချုပ်မှုပုံစံကို ရွေးချယ်ပေးပါ</i>', # MODIF
	'info_appliquer_choix_moderation' => 'ဆုံးဖြတ်ခြင်းအတွက် သည်ရွေးချယ်မှုကိုပြုလုပ်ပါ',
	'info_desactiver_forum_public' => 'အများဆိုင်ဖိုရမ်နှင့် ချိတ်ဆက်မှု မရနိုင်ပါ၊ ဆောင်းပါးများပေါ်မူတည်ပြီး အများဆိုင်ဖိုရမ်ကို ချိတ်ဆက်ခွင့်ပြုနိုင်သည်၊ 
၎င်းတို့သည် အခန်းကဏ္ဍအတွက် သတင်းစသည်များကို ခွင့်မပြုပါ',
	'info_envoi_forum' => 'ဆောင်းပါးရေးသည့် စာရေးသူများသို့ ဖိုရမ်လိပ်စာကို ပို့လိုက်ပါ',
	'info_fonctionnement_forum' => 'ဖိုရမ်​လုပ်ဆောင်မှု',
	'info_gauche_suivi_forum_2' => '<i>ဖို​ရမ်နောက်ဆက်တွဲ</i> စာမျက်နှာသည် သင့်ဝက်ဘ်ဆိုက်၏ စီမံခန့်ခွဲသည့် ကိရိယာဖြစ်သည် (ဆွေးနွေးမှု (သို့) ပြန်လည်ပြုပြင်သည့် ဧရိယာမဟုတ်ပါ) ၄င်းသည်ဤဆောင်းပါး၏ အများသုံးဖိုရမ်ထည့်ဝင်မှုများကို ဖော်ပြပြီး ထိုထည့်ဝင်မှုများကို စီမံခွင့်ပြူသည် (အများသုံးဝက်ဘ်ဆိုက်နှင့် ကိုယ်ပိုင်နေရာနှစ်ခုစလုံး)', # MODIF
	'info_liens_syndiques_3' => 'ဖိုရမ်များ',
	'info_liens_syndiques_4' => 'ဖြစ်ကြသည်',
	'info_liens_syndiques_5' => 'ဖိုရမ်',
	'info_liens_syndiques_6' => 'ဖြစ်သည်',
	'info_liens_syndiques_7' => 'စံနှုန်းကိုက်ညီမှုစစ်ဆေးချက်ပယ်ဖျက်သည်',
	'info_mode_fonctionnement_defaut_forum_public' => 'အများသုံးဖိုရမ်များ၏ အခြားလုပ်ဆောင်မှုပုံစံ',
	'info_option_email' => 'ဝင်ရောက်လည်ပတ်သူက ဆောင်းပါးနှင့်ပတ်သက်၍ မှတ်ချက်ထားရှိပါက ထို​ဆောင်းပါးရေးသူကို အီးမေးလ်ဖြင့် သတင်းပေးနိုင်သည်။ ဤရွေးချယ်မှုကို သုံးချင်ပါသလား', # MODIF
	'info_pas_de_forum' => 'ဖိုရမ်မရှိပါ',
	'item_activer_forum_administrateur' => 'ဝက်ဘ်ဆိုက်ကြီးကြပ်သူများဖိုရမ် ရနိုင်သည်',
	'item_desactiver_forum_administrateur' => 'ဝက်ဘ်ဆိုက်ကြီကြပ်သူများဖိုရမ် မရနိုင်ပါ',

	// L
	'lien_reponse_article' => 'ဆောင်းပါးသို့ ပြန်တုန့်ပြန်ပါ',
	'lien_reponse_breve_2' => 'သတင်းအချက်သို့ အကြောင်းပြန်ပါ',
	'lien_reponse_rubrique' => 'အခန်းကဏ္ဍသို့ အကြောင်းပြန်ပါ',
	'lien_reponse_site_reference' => 'ကိုးကားဝက်ဘ်ဆိုက်သို့ အကြောင်းပြန်ပါ', # MODIF

	// O
	'onglet_messages_internes' => 'အ​တွင်းဆိုင်စာစောင်များ',
	'onglet_messages_publics' => 'အ​များဆိုင်စာစောင်များ',
	'onglet_messages_vide' => 'စာသားမပါသည့်စာစောင်',

	// R
	'repondre_message' => 'ဤစာဆောင်ကိုပြန်ရန်',

	// S
	'statut_original' => 'မူရင်း',

	// T
	'titre_cadre_forum_administrateur' => 'ကြီးကြပ်သူ၏ ကိုယ်ပိုင်ဖိုရမ်',
	'titre_cadre_forum_interne' => 'ဖိုရမ်အတွင်းပိုင်း',
	'titre_forum' => 'ဖိုရမ်',
	'titre_forum_suivi' => 'နောက်ဆက်တွဲဖိုရမ်',
	'titre_page_forum_suivi' => 'ဖိုရမ်နောက်ဆက်တွဲ'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_my.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=my
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'လာမည့် ဆောင်ပါးအသစ်များ အ​တွက်သာ (သိုလောင် သိမ်းဆည်းထားသည်များနှင့်မဆိုင်)',
	'bouton_radio_articles_tous' => 'လုံးဝခြွင်းချက်မရှိ ဆောင်းပါးများ အလုံးသို့',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'ဆောင်းပါးများ အလုံးသို့၊ သို့သော် ဖိုရမ်ပိတ်ထားသော ဆောင်းပါးများမပါ',
	'bouton_radio_enregistrement_obligatoire' => 'မှတ်ပုံတင်ရန် လိုအပ်သည် (သုံးစွဲသူများ အနေဖြင့် အီးမေးလ်လိပ်စာ ပေးထားရပါမည်)',
	'bouton_radio_moderation_priori' => 'ကြိုတင် ထိန်းသိမ်းထားခြင်း (ပါဝင်ရေးသားချက်များသည် ကြီးကြပ်သူမှ စစ်ဆေးအတည်ပြုပြီးမှသာ အများဆိုင်စာမျက်နှာတွင် ပေါ်လာမည်)', # MODIF
	'bouton_radio_modere_abonnement' => 'မှတ်ပုံတင်ထားရန် လိုအပ်သည်',
	'bouton_radio_modere_posteriori' => 'နောက်မှ ထိန်းသိမ်းခြင်း', # MODIF
	'bouton_radio_modere_priori' => 'ကြိုတင် ထိန်းသိမ်းထားခြင်း', # MODIF
	'bouton_radio_publication_immediate' => 'ချက်ချင်းထုတ်ပြန်ခြင်းအတွက် သတင်းအချက်အလက် (ပါဝင်ရေးသားချက်များ ပို့​ပြီးပြီးခြင်း ဖော်ပြမည်၊ အဲဒီနောက် ကြီးကြပ်သူများမှ ပယ်ဖျက်နိုင်သည်)',

	// F
	'form_pet_message_commentaire' => 'မှတ်ချက် တစ်စုံတစ်ရာ ပေးလိုပါသလား?',
	'forum' => 'ဖိုရမ်',
	'forum_acces_refuse' => 'ဤဖိုရမ်သို့ ဝင်ရောက်ခွင့် မရှိတော့ပါ',
	'forum_attention_dix_caracteres' => '<b>သတိပေးချက်!</b> သင့်စာစောင်သည် အနည်းဆုံး စာလုံး၁ဝလုံးနှင့် အထက်ပါဝင်သင့်သည်',
	'forum_attention_trois_caracteres' => '<b>သတိပေးချက်!</b> သင့်ခေါင်းစဉ်သည် အနည်းဆုံး စာလုံး၃လုံးနှင့် အထက်ပါဝင်သင့်သည်',
	'forum_attention_trop_caracteres' => '<b>သတိပေးချက် !</b> သင့်စာစောင် (@compte@ characters) သည် သိမ်းဆည်းရန် ရှည်လွန်းသည်၊ ​အများဆုံး စာလုံး @max@သာ ပါဝင်သင့်သည်', # MODIF
	'forum_avez_selectionne' => 'သင်ရွေးချယ်ခဲ့ပြီးပြီ',
	'forum_cliquer_retour' => 'ဤနေရာကို <a href=\'@retour_forum@\'>နှိပ်ပြီး</a> ဆက်သွားပါ',
	'forum_forum' => 'ဖိုရမ်',
	'forum_info_modere' => 'ဤဖိုရမ်သည် အတည်ပြုချက်လိုအပ်​သည်၊ သင့်ပါဝင်ရေးသားမှုသည် ဆိုက်ကြီးကြပ်သူမှ အတည်ပြုပြီးရင် ပေါ်လာပါလိမ့်မည်', # MODIF
	'forum_lien_hyper' => '<b>Hypertext ဆက်သွယ်မှု</b> (optional)', # MODIF
	'forum_message_definitif' => 'ဆိုက်သို့ပို့ပြီးကြောင်း နောက်ဆုံးအကြောင်းကြားခြင်း',
	'forum_message_trop_long' => 'သင့်စာစောင် အလွန်ရှည်ပါသည်၊ အများဆုံး စာလုံး ၂ဝဝဝဝ သာရှိသင့်သည်', # MODIF
	'forum_ne_repondez_pas' => 'ဤမေးလ်ကို တိုက်ရိုက် အကြောင်းမပြန်ပါနှင့်၊ အောက်ပါလိပ်စာမှ ပြန်ပါ', # MODIF
	'forum_page_url' => '(သင့်ဆောင်ပါး ထုတ်ဝေမှုကို ဒီစာစောင်မ ညွှန်းထားတယ်ဆိုရင်တော့၊ အောက်ဖော်ပြပါနေရာတွင် စာမျက်နှာခေါင်းစဉ်နှင့် လိပ်စာကိုထည့်သွင်းပါ။)',
	'forum_poste_par' => 'သင့်ဆောင်းပါး \\"@titre@\\" တင်သွင်းပြီးကြောင်း @parauteur@', # MODIF
	'forum_qui_etes_vous' => '<b>သင်ဘယ်သူလဲ?</b> (optional)', # MODIF
	'forum_texte' => 'သင့်စာစောင်၏ စာသားများ', # MODIF
	'forum_titre' => 'အကြောင်းအရာ', # MODIF
	'forum_url' => 'ဝက်ဘ်လိပ်စာ', # MODIF
	'forum_valider' => 'ဤရွေးချယ်မှုကို အတည်ပြုရန်',
	'forum_voir_avant' => 'စာစောင်မတင်သွင်းမှီ အရင်ကြည့်ရှုရန်', # MODIF
	'forum_votre_email' => 'သင့်အီးမေးလ်လိပ်စာ', # MODIF
	'forum_votre_nom' => 'သင့်နာမည်', # MODIF
	'forum_vous_enregistrer' => 'သင့်ကိုပေးထားသော မှတ်ပုံတင်နံပါတ်နှင့်ဝင်ပါ သို့မဟုတ် ဤဖိုရမ်ထဲ အထူးနေရာမှ ပါဝင် ရန် အရင်မှတ်ပုံတင်ပါ',
	'forum_vous_inscrire' => 'မှတ်ပုံတင်ရန်',

	// I
	'icone_poster_message' => 'စာတစောင်ပို့ပါ',
	'icone_suivi_forum' => 'နောက်ဆက်တွဲဖိုရမ် @nb_forums@ ပါဝင်မှု(များ)',
	'icone_suivi_forums' => 'ဖိုရမ်ကို စီမံရန်',
	'icone_supprimer_message' => 'ဤစာစောင်ကို ပယ်ဖျက်ရန်',
	'icone_valider_message' => 'ဤစာစောင်ကို အတည်ပြုရန်',
	'info_activer_forum_public' => '<i>အများသုံးဖိုရမ်သို့ ဝင်ရောက်ရန်အတွက် အခြားထိန်းချုပ်မှုပုံစံကို ရွေးချယ်ပေးပါ</i>', # MODIF
	'info_appliquer_choix_moderation' => 'ဆုံးဖြတ်ခြင်းအတွက် သည်ရွေးချယ်မှုကိုပြုလုပ်ပါ',
	'info_desactiver_forum_public' => 'အများဆိုင်ဖိုရမ်နှင့် ချိတ်ဆက်မှု မရနိုင်ပါ၊ ဆောင်းပါးများပေါ်မူတည်ပြီး အများဆိုင်ဖိုရမ်ကို ချိတ်ဆက်ခွင့်ပြုနိုင်သည်၊ 
၎င်းတို့သည် အခန်းကဏ္ဍအတွက် သတင်းစသည်များကို ခွင့်မပြုပါ',
	'info_envoi_forum' => 'ဆောင်းပါးရေးသည့် စာရေးသူများသို့ ဖိုရမ်လိပ်စာကို ပို့လိုက်ပါ',
	'info_fonctionnement_forum' => 'ဖိုရမ်​လုပ်ဆောင်မှု',
	'info_gauche_suivi_forum_2' => '<i>ဖို​ရမ်နောက်ဆက်တွဲ</i> စာမျက်နှာသည် သင့်ဝက်ဘ်ဆိုက်၏ စီမံခန့်ခွဲသည့် ကိရိယာဖြစ်သည် (ဆွေးနွေးမှု (သို့) ပြန်လည်ပြုပြင်သည့် ဧရိယာမဟုတ်ပါ) ၄င်းသည်ဤဆောင်းပါး၏ အများသုံးဖိုရမ်ထည့်ဝင်မှုများကို ဖော်ပြပြီး ထိုထည့်ဝင်မှုများကို စီမံခွင့်ပြူသည် (အများသုံးဝက်ဘ်ဆိုက်နှင့် ကိုယ်ပိုင်နေရာနှစ်ခုစလုံး)', # MODIF
	'info_liens_syndiques_3' => 'ဖိုရမ်များ',
	'info_liens_syndiques_4' => 'ဖြစ်ကြသည်',
	'info_liens_syndiques_5' => 'ဖိုရမ်',
	'info_liens_syndiques_6' => 'ဖြစ်သည်',
	'info_liens_syndiques_7' => 'စံနှုန်းကိုက်ညီမှုစစ်ဆေးချက်ပယ်ဖျက်သည်',
	'info_mode_fonctionnement_defaut_forum_public' => 'အများသုံးဖိုရမ်များ၏ အခြားလုပ်ဆောင်မှုပုံစံ',
	'info_option_email' => 'ဝင်ရောက်လည်ပတ်သူက ဆောင်းပါးနှင့်ပတ်သက်၍ မှတ်ချက်ထားရှိပါက ထို​ဆောင်းပါးရေးသူကို အီးမေးလ်ဖြင့် သတင်းပေးနိုင်သည်။ ဤရွေးချယ်မှုကို သုံးချင်ပါသလား', # MODIF
	'info_pas_de_forum' => 'ဖိုရမ်မရှိပါ',
	'item_activer_forum_administrateur' => 'ဝက်ဘ်ဆိုက်ကြီးကြပ်သူများဖိုရမ် ရနိုင်သည်',
	'item_desactiver_forum_administrateur' => 'ဝက်ဘ်ဆိုက်ကြီကြပ်သူများဖိုရမ် မရနိုင်ပါ',

	// L
	'lien_reponse_article' => 'ဆောင်းပါးသို့ ပြန်တုန့်ပြန်ပါ',
	'lien_reponse_breve_2' => 'သတင်းအချက်သို့ အကြောင်းပြန်ပါ',
	'lien_reponse_rubrique' => 'အခန်းကဏ္ဍသို့ အကြောင်းပြန်ပါ',
	'lien_reponse_site_reference' => 'ကိုးကားဝက်ဘ်ဆိုက်သို့ အကြောင်းပြန်ပါ', # MODIF

	// O
	'onglet_messages_internes' => 'အ​တွင်းဆိုင်စာစောင်များ',
	'onglet_messages_publics' => 'အ​များဆိုင်စာစောင်များ',
	'onglet_messages_vide' => 'စာသားမပါသည့်စာစောင်',

	// R
	'repondre_message' => 'ဤစာဆောင်ကိုပြန်ရန်',

	// S
	'statut_original' => 'မူရင်း',

	// T
	'titre_cadre_forum_administrateur' => 'ကြီးကြပ်သူ၏ ကိုယ်ပိုင်ဖိုရမ်',
	'titre_cadre_forum_interne' => 'ဖိုရမ်အတွင်းပိုင်း',
	'titre_forum' => 'ဖိုရမ်',
	'titre_forum_suivi' => 'နောက်ဆက်တွဲဖိုရမ်',
	'titre_page_forum_suivi' => 'ဖိုရမ်နောက်ဆက်တွဲ',
];
